@@ -1,9 +1,9 @@
 package IMDB::TitlePage::Extract;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-23'; # DATE
+our $DATE = '2019-12-28'; # DATE
 our $DIST = 'IMDB-TitlePage-Extract'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -81,7 +81,7 @@ sub parse_imdb_title_page {
         if $ct =~ m!<div class="summary_text"[^>]*>\s*(.+?)\s*</div>!s;
 
     $res->{duration} //= $1
-        if $ct =~ m!<time itemprop="duration" datetime="PT(\d+)M!;
+        if $ct =~ m!<time itemprop="duration" datetime="(PT.+?)"!;
 
     [200, "OK", $res, $resmeta];
 }
@@ -101,7 +101,7 @@ IMDB::TitlePage::Extract - Extract information from an IMDB title page
 
 =head1 VERSION
 
-This document describes version 0.002 of IMDB::TitlePage::Extract (from Perl distribution IMDB-TitlePage-Extract), released on 2019-12-23.
+This document describes version 0.003 of IMDB::TitlePage::Extract (from Perl distribution IMDB-TitlePage-Extract), released on 2019-12-28.
 
 =head1 FUNCTIONS
 
